from setuptools import setup

setup(
    name='ACNLoggerAV',    # This is the name of your PyPI-package.
    version='1.0.1',           # The name of your scipt, and also the command you'll be using for calling it
    author='AIIberia',
    author_email='acn.av.endesa@gmail.com',
    packages=['ACNLoggerAV']
)
